@@ -20,9 +20,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
+#include <config.h>
 
 #include <stdio.h>
 #include <locale.h>
@@ -65,7 +63,7 @@ check_font_contain_text (FT_Face face,
   gunichar *string;
   glong len, idx, map;
   FT_CharMap charmap;
-  gboolean retval;
+  gboolean retval = FALSE;
 
   string = g_utf8_to_ucs4_fast (text, -1, &len);
 
@@ -183,6 +181,8 @@ main (int argc,
     cairo_font_face_t *font;
     gchar *str = NULL;
     gdouble scale, scale_x, scale_y;
+    gint face_index = 0;
+    gchar *fragment;
 
     const GOptionEntry options[] = {
 	    { "text", 't', 0, G_OPTION_ARG_STRING, &thumbstr_utf8,
@@ -233,11 +233,15 @@ main (int argc,
 
     totem_resources_monitor_start (arguments[0], 30 * G_USEC_PER_SEC);
 
+    fragment = strrchr (arguments[0], '#');
+    if (fragment)
+	face_index = strtol (fragment + 1, NULL, 0);
+
     file = g_file_new_for_commandline_arg (arguments[0]);
     uri = g_file_get_uri (file);
     g_object_unref (file);
 
-    face = sushi_new_ft_face_from_uri (library, uri, &contents, &gerror);
+    face = sushi_new_ft_face_from_uri (library, uri, face_index, &contents, &gerror);
     if (gerror) {
 	g_printerr ("Could not load face '%s': %s\n", uri,
 		    gerror->message);
